@@ -63,6 +63,7 @@
 #include "gdk/gdk.h"
 #include "gdk/gdkkeysyms.h"
 #include "lib/properties.h"
+#include "dia-props.h"
 
 #ifdef HAVE_GDK_PIXBUF
 GdkPixbuf *logo;
@@ -445,6 +446,7 @@ help_about_callback(GtkWidget *widget, gpointer data)
 
   static const gchar *contributors[] = {
     "Jerome Abela",
+    "Hans Breuer",
     "Emmanuel Briot",
     "Cyrille Chepelov",
     "Lars R. Clausen",
@@ -493,6 +495,8 @@ help_about_callback(GtkWidget *widget, gpointer data)
 
       gdk_pixbuf_render_pixmap_and_mask(logo, &pixmap, &bitmap, 128);
       gpixmap = gtk_pixmap_new(pixmap, bitmap);
+      gdk_pixmap_unref(pixmap);
+      gdk_bitmap_unref(bitmap);
 #else
       gdk_imlib_render(logo, logo->rgb_width, logo->rgb_height);
       frame = gtk_frame_new (NULL);
@@ -654,11 +658,18 @@ view_aa_callback(gpointer callback_data,
 {
   DDisplay *ddisp;
   int aa;
+  static gboolean shown_warning = FALSE;
 
   ddisp = ddisplay_active();
   
   aa = GTK_CHECK_MENU_ITEM (widget)->active;
 
+  if (aa && !shown_warning)
+    message_warning(_("The anti aliased renderer is buggy, and may cause\n"
+		      "crashes.  We know there are bugs in it, so don't\n"
+		      "bother submitting another report if it crashes"));
+  shown_warning = TRUE;
+
   if (aa != ddisp->aa_renderer) {
     ddisplay_set_renderer(ddisp, aa);
     ddisplay_add_update_all(ddisp);
@@ -802,14 +813,13 @@ view_show_all_callback(GtkWidget *widget, gpointer data)
   ddisplay_flush(ddisp);
 }
 
-
 void
-view_edit_grid_callback(GtkWidget *widget, gpointer data)
+view_diagram_properties_callback(GtkWidget *widget, gpointer data)
 {
   DDisplay *ddisp;
-  
+
   ddisp = ddisplay_active();
-  grid_show_dialog(&ddisp->grid, ddisp);
+  diagram_properties_show(ddisp->diagram);
 }
 
 
