@@ -27,20 +27,44 @@
 #include "focus.h"
 #include "message.h"
 #include "menus.h"
+#include "preferences.h"
 #include "properties.h"
 #include "cut_n_paste.h"
 #include "layer_dialog.h"
 #include "app_procs.h"
 #include "dia_dirs.h"
+#include "load_save.h"
 
 GList *open_diagrams = NULL;
 
+Diagram *
+diagram_load(const char *filename, DiaImportFilter *ifilter)
+{
+  Diagram *diagram;
+
+  if (!ifilter)
+    ifilter = filter_guess_import_filter(filename);
+  if (!ifilter)  /* default to native format */
+    ifilter = &dia_import_filter;
+  diagram = new_diagram(filename);
+  if (ifilter->import(filename, diagram->data)) {
+    diagram->unsaved = FALSE;
+    diagram_set_modified(diagram, FALSE);
+  } else {
+    diagram_destroy(diagram);
+    diagram = NULL;
+  }
+  return diagram;
+}
+
 Diagram *
 new_diagram(const char *filename)  /* Note: filename is copied */
 {
   Diagram *dia = g_new(Diagram, 1);
   
   dia->data = new_diagram_data();
+  dia->data->grid.width_x = prefs.grid.x;
+  dia->data->grid.width_y = prefs.grid.y;
 
   dia->filename = g_strdup(filename);
   
