@@ -26,23 +26,11 @@ typedef struct _Grid Grid;
 struct _Grid {
   guint visible;
   guint snap;
-  real width_x;
-  real width_y;
-  
-  GdkGC *gc;
-
-  GtkWidget *dialog;         /* The dialog for changing the grid  */
-  GtkWidget *entry_x;
-  gint handler_x;
-  GtkWidget *entry_y;
-  gint handler_y;
 };
 
 #include "display.h"
 
-extern void grid_draw(DDisplay *ddisp, Rectangle *update);
-extern void snap_to_grid(Grid *grid, coord *x, coord *y);
-extern void grid_show_dialog(Grid *grid, DDisplay *ddisp);
-extern void grid_destroy_dialog(Grid *grid);
+void grid_draw(DDisplay *ddisp, Rectangle *update);
+void snap_to_grid(DDisplay *ddisp, coord *x, coord *y);
 
 #endif GRID_H
