@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-/* $Header: /cvs/gnome/dia/app/interface.c,v 1.35 2000/05/09 11:49:17 jamesh Exp $ */
+/* $Header: /cvs/gnome/dia/app/interface.c,v 1.43 2000/07/31 06:12:47 jamesh Exp $ */
 
 #include "config.h"
 
@@ -66,6 +66,11 @@ ToolButton tool_data[] =
     N_("Polygon"),
     { CREATE_OBJECT_TOOL, "Standard - Polygon", NULL }
   },
+  { NULL,
+    N_("Create Beziergon"),
+    N_("Beziergon"),
+    { CREATE_OBJECT_TOOL, "Standard - Beziergon", NULL }
+  },
   { NULL,
     N_("Create Line"),
     N_("Line"),
@@ -111,26 +116,33 @@ static GSList *tool_group = NULL;
 
 GtkWidget *modify_tool_button;
 
-/*  If we create *all* menus at startup, we can read a .menurc file and
- *  get persistent menu shortcuts.  Yummy!
- */
-void
-create_menus() {
-}
-
-
 /*  The popup shell is a pointer to the display shell that posted the latest
  *  popup menu.  When this is null, and a command is invoked, then the
  *  assumption is that the command was a result of a keyboard accelerator
  */
 GtkWidget *popup_shell = NULL;
 
+static gint
+origin_button_press(GtkWidget *widget, GdkEventButton *event, gpointer data)
+{
+  DDisplay *ddisp = (DDisplay *)data;
+
+  display_set_active(ddisp);
+  ddisplay_popup_menu(ddisp, event);
+
+  /* stop the signal emission so the button doesn't grab the
+   * pointer from us */
+  gtk_signal_emit_stop_by_name(GTK_OBJECT(widget), "button_press_event");
+
+  return FALSE;
+}
+
 void
 create_display_shell(DDisplay *ddisp,
 		     int width, int height,
 		     char *title, int top_level_window)
 {
-  GtkWidget *table;
+  GtkWidget *table, *widget;
   GtkWidget *status_hbox;
   int s_width, s_height;
 
@@ -170,6 +182,18 @@ create_display_shell(DDisplay *ddisp,
   gtk_signal_connect (GTK_OBJECT (ddisp->shell), "destroy",
                       GTK_SIGNAL_FUNC (ddisplay_destroy),
                       ddisp);
+  gtk_signal_connect (GTK_OBJECT (ddisp->shell), "focus_out_event",
+		      GTK_SIGNAL_FUNC (ddisplay_focus_out_event),
+		      ddisp);
+  gtk_signal_connect (GTK_OBJECT (ddisp->shell), "focus_in_event",
+		      GTK_SIGNAL_FUNC (ddisplay_focus_in_event),
+		      ddisp);
+  gtk_signal_connect (GTK_OBJECT (ddisp->shell), "realize",
+                      GTK_SIGNAL_FUNC (ddisplay_realize),
+                      ddisp);
+  gtk_signal_connect (GTK_OBJECT (ddisp->shell), "unrealize",
+                      GTK_SIGNAL_FUNC (ddisplay_unrealize),
+		      ddisp);
 
   /* Clipboard handling signals */
   gtk_signal_connect (GTK_OBJECT(ddisp->shell), "selection_get",
@@ -187,8 +211,13 @@ create_display_shell(DDisplay *ddisp,
   gtk_container_add (GTK_CONTAINER (ddisp->shell), table);
 
   /*  scrollbars, rulers, canvas, menu popup button  */
-  ddisp->origin = gtk_frame_new (NULL);
-  gtk_frame_set_shadow_type (GTK_FRAME (ddisp->origin), GTK_SHADOW_OUT);
+  ddisp->origin = gtk_button_new();
+  GTK_WIDGET_UNSET_FLAGS(ddisp->origin, GTK_CAN_FOCUS);
+  widget = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_OUT);
+  gtk_container_add(GTK_CONTAINER(ddisp->origin), widget);
+  gtk_widget_show(widget);
+  gtk_signal_connect(GTK_OBJECT(ddisp->origin), "button_press_event",
+		     GTK_SIGNAL_FUNC(origin_button_press), ddisp);
 
   ddisp->hrule = gtk_hruler_new ();
   gtk_signal_connect_object (GTK_OBJECT (ddisp->shell), "motion_notify_event",
@@ -237,27 +266,9 @@ create_display_shell(DDisplay *ddisp,
   gtk_table_attach (GTK_TABLE (table), ddisp->vsb, 2, 3, 0, 2,
                     GTK_FILL, GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
 
-  /*  the popup menu  */
-#ifdef GNOME
-  ddisp->popup = gnome_display_menus_create ();
-  ddisp->accel_group = gnome_popup_menu_get_accel_group(GTK_MENU(ddisp->popup));
-#else
-  menus_get_image_menu (&ddisp->popup, &ddisp->accel_group);
-#endif
-
-  if (top_level_window) {
-    gchar *accelfilename = dia_config_filename("menus/display");
-
-    /*  the accelerator table/group for the popup */
-    gtk_window_add_accel_group (GTK_WINDOW(ddisp->shell),
-				ddisp->accel_group);
-    
-    if (accelfilename) {
-      gtk_item_factory_parse_rc(accelfilename);
-      g_free(accelfilename);
-    }
-  }
-
+  menus_get_image_menu (NULL, &ddisp->accel_group);
+  if (top_level_window)
+    gtk_window_add_accel_group(GTK_WINDOW(ddisp->shell), ddisp->accel_group);
 
   /* the statusbars */
   status_hbox = gtk_hbox_new (FALSE, 2);
@@ -341,9 +352,6 @@ tool_select_callback(GtkWidget *widget, gpointer data) {
 static void
 create_tools(GtkWidget *parent)
 {
-#ifndef USE_WRAPBOX
-  GtkWidget *table;
-#endif
   GtkWidget *button;
   GtkWidget *pixmapwidget;
   GdkPixmap *pixmap;
@@ -353,32 +361,14 @@ create_tools(GtkWidget *parent)
   char **pixmap_data;
   int i;
 
-#ifndef USE_WRAPBOX
-  table = gtk_table_new (ROWS, COLUMNS, FALSE);
-  gtk_box_pack_start (GTK_BOX (parent), table, FALSE, TRUE, 0);
-#endif
-
   for (i = 0; i < NUM_TOOLS; i++) {
     tool_widgets[i] = button = gtk_radio_button_new (tool_group);
     gtk_container_set_border_width (GTK_CONTAINER (button), 0);
     tool_group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (button), FALSE);
 
-#ifdef USE_WRAPBOX
     gtk_wrap_box_pack(GTK_WRAP_BOX(parent), button,
-# if 1 /* HB: IHMO even 13 buttons look better when stretched to parent */
 		      TRUE, TRUE, FALSE, TRUE);
-# else
-		      FALSE, TRUE, FALSE, TRUE);
-# endif
-#else
-    gtk_table_attach (GTK_TABLE (table), button,
-		      (i % COLUMNS), (i % COLUMNS) + 1,
-		      (i / COLUMNS), (i / COLUMNS) + 1,
-		      GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-		      GTK_FILL,
-		      0, 0);
-#endif
 
     if (tool_data[i].callback_data.type == MODIFY_TOOL) {
       modify_tool_button = GTK_WIDGET(button);
@@ -423,11 +413,13 @@ create_tools(GtkWidget *parent)
     gtk_widget_show (pixmapwidget);
     gtk_widget_show (button);
   }
-#ifndef USE_WRAPBOX
-  gtk_widget_show(table);
-#endif
 }
 
+static GtkWidget *sheet_option_menu;
+static GtkWidget *sheet_menu;
+static GtkWidget *sheet_wbox;
+
+#if 0
 static GtkWidget *
 create_sheet_page(GtkWidget *parent, Sheet *sheet)
 {
@@ -453,14 +445,10 @@ create_sheet_page(GtkWidget *parent, Sheet *sheet)
   if (rows<1)
     rows = 1;
   
-#ifdef USE_WRAPBOX
   table = gtk_hwrap_box_new(FALSE);
   gtk_wrap_box_set_aspect_ratio(GTK_WRAP_BOX(table), COLUMNS * 1.0 / rows);
   gtk_wrap_box_set_justify(GTK_WRAP_BOX(table), GTK_JUSTIFY_TOP);
   gtk_wrap_box_set_line_justify(GTK_WRAP_BOX(table), GTK_JUSTIFY_LEFT);
-#else
-  table = gtk_table_new (rows, COLUMNS, TRUE);
-#endif
 
   style = gtk_widget_get_style(parent);
 
@@ -497,19 +485,10 @@ create_sheet_page(GtkWidget *parent, Sheet *sheet)
 
 
     gtk_container_add (GTK_CONTAINER (button), pixmapwidget);
-#ifdef USE_WRAPBOX
     gtk_wrap_box_pack(GTK_WRAP_BOX(table), button,
 		      FALSE, TRUE, FALSE, TRUE);
     if (sheet_obj->line_break)
       gtk_wrap_box_set_child_forced_break(GTK_WRAP_BOX(table),button,TRUE);
-#else
-    gtk_table_attach (GTK_TABLE (table), button,
-		      (i % COLUMNS), (i % COLUMNS) + 1,
-		      (i / COLUMNS), (i / COLUMNS) + 1,
-		      GTK_EXPAND | GTK_SHRINK | GTK_FILL,
-		      GTK_FILL,
-		      0, 0);
-#endif
 
     /* This is a Memory leak, these can't be freed.
        Doesn't matter much anyway... */
@@ -539,70 +518,156 @@ create_sheet_page(GtkWidget *parent, Sheet *sheet)
   
   return scrolled_window;
 }
+#endif
+
+static void
+fill_sheet_wbox(GtkWidget *menu_item, Sheet *sheet)
+{
+  int rows;
+  GtkStyle *style;
+  GSList *tmp;
+
+  gtk_container_foreach(GTK_CONTAINER(sheet_wbox),
+			(GtkCallback)gtk_widget_destroy, NULL);
+  tool_group = gtk_radio_button_group(GTK_RADIO_BUTTON(tool_widgets[0]));
+
+  /* set the aspect ratio on the wbox */
+  rows = (g_slist_length(sheet->objects) - 1) / COLUMNS + 1;
+  if (rows<1) rows = 1;
+  gtk_wrap_box_set_aspect_ratio(GTK_WRAP_BOX(sheet_wbox),
+				COLUMNS * 1.0 / rows);
+  style = gtk_widget_get_style(sheet_wbox);
+  for (tmp = sheet->objects; tmp != NULL; tmp = tmp->next) {
+    SheetObject *sheet_obj = tmp->data;
+    GdkPixmap *pixmap;
+    GdkBitmap *mask;
+    GtkWidget *pixmapwidget;
+    GtkWidget *button;
+    ToolButtonData *data;
+
+    if (sheet_obj->pixmap != NULL) {
+      pixmap = gdk_pixmap_colormap_create_from_xpm_d(NULL,
+			gtk_widget_get_colormap(sheet_wbox), &mask, 
+			&style->bg[GTK_STATE_NORMAL], sheet_obj->pixmap);
+    } else if (sheet_obj->pixmap_file != NULL) {
+      pixmap = gdk_pixmap_colormap_create_from_xpm(NULL,
+			gtk_widget_get_colormap(sheet_wbox), &mask,
+			&style->bg[GTK_STATE_NORMAL], sheet_obj->pixmap_file);
+    } else {
+      ObjectType *type;
+      type = object_get_type(sheet_obj->object_type);
+      pixmap = gdk_pixmap_colormap_create_from_xpm_d(NULL,
+			gtk_widget_get_colormap(sheet_wbox), &mask, 
+			&style->bg[GTK_STATE_NORMAL], type->pixmap);
+    }
+    if (pixmap) {
+      pixmapwidget = gtk_pixmap_new(pixmap, mask);
+      gdk_pixmap_unref(pixmap);
+      if (mask) gdk_bitmap_unref(mask);
+    } else
+      pixmapwidget = gtk_type_new(gtk_pixmap_get_type());
+
+    button = gtk_radio_button_new (tool_group);
+    gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (button), FALSE);
+    gtk_container_set_border_width (GTK_CONTAINER (button), 0);
+    tool_group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+
+    gtk_container_add (GTK_CONTAINER (button), pixmapwidget);
+    gtk_widget_show(pixmapwidget);
+
+    gtk_wrap_box_pack(GTK_WRAP_BOX(sheet_wbox), button,
+		      FALSE, TRUE, FALSE, TRUE);
+    gtk_widget_show(button);
+    if (sheet_obj->line_break)
+      gtk_wrap_box_set_child_forced_break(GTK_WRAP_BOX(sheet_wbox),
+					  button, TRUE);
+
+    data = g_new(ToolButtonData, 1);
+    data->type = CREATE_OBJECT_TOOL;
+    data->extra_data = sheet_obj->object_type;
+    data->user_data = sheet_obj->user_data;
+    gtk_object_set_data_full(GTK_OBJECT(button), "Dia::ToolButtonData",
+			     data, (GdkDestroyNotify)g_free);
+    
+    gtk_signal_connect (GTK_OBJECT (button), "toggled",
+			GTK_SIGNAL_FUNC (tool_select_update), data);
+    gtk_signal_connect (GTK_OBJECT (button), "button_press_event",
+			GTK_SIGNAL_FUNC (tool_button_press), data);
+
+    gtk_tooltips_set_tip (tool_tips, button,
+			  gettext(sheet_obj->description), NULL);
+  }
+}
+
+static void
+fill_sheet_menu(void)
+{
+  GSList *tmp;
+
+  gtk_container_foreach(GTK_CONTAINER(sheet_menu),
+			(GtkCallback)gtk_widget_destroy, NULL);
+  gtk_widget_ref(sheet_menu);
+  gtk_option_menu_remove_menu(GTK_OPTION_MENU(sheet_option_menu));
+  for (tmp = get_sheets_list(); tmp != NULL; tmp = tmp->next) {
+    Sheet *sheet = tmp->data;
+    GtkWidget *menuitem;
+
+    if (sheet->objects == NULL)
+      continue;
+
+    menuitem = gtk_menu_item_new_with_label(gettext(sheet->name));
+    gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
+		       GTK_SIGNAL_FUNC(fill_sheet_wbox), sheet);
+    gtk_container_add(GTK_CONTAINER(sheet_menu), menuitem);
+    gtk_widget_show(menuitem);
+  }
+  gtk_option_menu_set_menu(GTK_OPTION_MENU(sheet_option_menu), sheet_menu);
+  gtk_widget_unref(sheet_menu);
+  gtk_menu_item_activate(
+	GTK_MENU_ITEM(GTK_OPTION_MENU(sheet_option_menu)->menu_item));
+}
 
 static void
 create_sheets(GtkWidget *parent)
 {
-  GtkWidget *notebook;
   GtkWidget *separator;
-  GSList *list;
-  Sheet *sheet;
-  GtkWidget *child;
   GtkWidget *label;
-  GtkWidget *menu_label;
+  GtkWidget *swin;
   
   separator = gtk_hseparator_new ();
-#ifdef USE_WRAPBOX
-  /* add a bit of padding around the label */
+  /* add a bit of padding around the separator */
   label = gtk_vbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(label), separator, TRUE, TRUE, 3);
   gtk_widget_show(label);
 
   gtk_wrap_box_pack (GTK_WRAP_BOX(parent), label, TRUE,TRUE, FALSE,FALSE);
   gtk_wrap_box_set_child_forced_break(GTK_WRAP_BOX(parent), label, TRUE);
-#else
-  gtk_box_pack_start (GTK_BOX (parent), separator, FALSE, TRUE, 3);
-#endif
   gtk_widget_show(separator);
 
-  notebook = gtk_notebook_new ();
-  /*
-  gtk_signal_connect (GTK_OBJECT (notebook), "switch_page",
-		      GTK_SIGNAL_FUNC (page_switch), NULL);
-  */
-  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
-  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), TRUE);
-  gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
-  gtk_notebook_popup_enable (GTK_NOTEBOOK (notebook));
-  gtk_container_set_border_width (GTK_CONTAINER (notebook), 1);
-#ifdef USE_WRAPBOX
-  gtk_wrap_box_pack(GTK_WRAP_BOX(parent), notebook, TRUE, TRUE, TRUE, TRUE);
-  gtk_wrap_box_set_child_forced_break(GTK_WRAP_BOX(parent), notebook, TRUE);
-#else
-  gtk_box_pack_start (GTK_BOX (parent), notebook, TRUE, TRUE, 0);
-#endif
-  
-  list = get_sheets_list();
-  while (list != NULL) {
-    sheet = (Sheet *) list->data;
+  sheet_option_menu = gtk_option_menu_new();
+  gtk_widget_set_usize(sheet_option_menu, 20, -1);
+  sheet_menu = gtk_menu_new();
+  gtk_option_menu_set_menu(GTK_OPTION_MENU(sheet_option_menu), sheet_menu);
+  gtk_wrap_box_pack(GTK_WRAP_BOX(parent), sheet_option_menu,
+		    TRUE, TRUE, FALSE, FALSE);
+  gtk_wrap_box_set_child_forced_break(GTK_WRAP_BOX(parent), sheet_option_menu,
+				      TRUE);
+  gtk_widget_show(sheet_option_menu);
 
-    label = gtk_label_new(gettext(sheet->name));
-    menu_label = gtk_label_new(gettext(sheet->name));
-    gtk_misc_set_alignment(GTK_MISC(menu_label), 0.0, 0.5);
-    
-    child = create_sheet_page(notebook, sheet);
-    
-    gtk_widget_show(label);
-    gtk_widget_show(menu_label);
-    gtk_widget_show_all(child);
+  swin = gtk_scrolled_window_new(NULL, NULL);
+  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swin),
+				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  gtk_wrap_box_pack(GTK_WRAP_BOX(parent), swin, TRUE, TRUE, TRUE, TRUE);
+  gtk_wrap_box_set_child_forced_break(GTK_WRAP_BOX(parent), swin, TRUE);
+  gtk_widget_show(swin);
 
-    gtk_notebook_append_page_menu (GTK_NOTEBOOK (notebook),
-				   child, label, menu_label);
-    
-    list = g_slist_next(list);
-  }
-  
-  gtk_widget_show(notebook);
+  sheet_wbox = gtk_hwrap_box_new(FALSE);
+  gtk_wrap_box_set_justify(GTK_WRAP_BOX(sheet_wbox), GTK_JUSTIFY_TOP);
+  gtk_wrap_box_set_line_justify(GTK_WRAP_BOX(sheet_wbox), GTK_JUSTIFY_LEFT);
+  gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(swin), sheet_wbox);
+  gtk_widget_show(sheet_wbox);
+
+  fill_sheet_menu();
 }
 
 static void
@@ -632,12 +697,8 @@ create_color_area (GtkWidget *parent)
 
   frame = gtk_frame_new (NULL);
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
-#ifdef USE_WRAPBOX
   gtk_wrap_box_pack(GTK_WRAP_BOX(parent), frame, TRUE, TRUE, FALSE, FALSE);
   gtk_wrap_box_set_child_forced_break(GTK_WRAP_BOX(parent), frame, TRUE);
-#else
-  gtk_box_pack_start (GTK_BOX (parent), frame, FALSE, FALSE, 0);
-#endif
   gtk_widget_realize (frame);
 
   hbox = gtk_hbox_new (FALSE, 1);
@@ -696,40 +757,19 @@ change_line_style(LineStyle lstyle, real dash_length, gpointer user_data)
 static void
 create_lineprops_area(GtkWidget *parent)
 {
-#ifndef USE_WRAPBOX
-  GtkWidget *hbox;
-#endif
   GtkWidget *chooser;
 
-#ifndef USE_WRAPBOX
-  hbox = gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (parent), hbox, FALSE, FALSE, 0);
-  gtk_widget_show(hbox);
-#endif
-
   chooser = dia_arrow_chooser_new(TRUE, change_start_arrow_style, NULL);
-#ifdef USE_WRAPBOX
   gtk_wrap_box_pack(GTK_WRAP_BOX(parent), chooser, FALSE, TRUE, FALSE, TRUE);
   gtk_wrap_box_set_child_forced_break(GTK_WRAP_BOX(parent), chooser, TRUE);
-#else
-  gtk_box_pack_start(GTK_BOX(hbox), chooser, FALSE, TRUE, 0);
-#endif
   gtk_widget_show(chooser);
 
   chooser = dia_line_chooser_new(change_line_style, NULL);
-#ifdef USE_WRAPBOX
   gtk_wrap_box_pack(GTK_WRAP_BOX(parent), chooser, TRUE, TRUE, FALSE, TRUE);
-#else
-  gtk_box_pack_start(GTK_BOX(hbox), chooser, TRUE, TRUE, 0);
-#endif
   gtk_widget_show(chooser);
 
   chooser = dia_arrow_chooser_new(FALSE, change_end_arrow_style, NULL);
-#ifdef USE_WRAPBOX
   gtk_wrap_box_pack(GTK_WRAP_BOX(parent), chooser, FALSE, TRUE, FALSE, TRUE);
-#else
-  gtk_box_pack_start(GTK_BOX(hbox), chooser, FALSE, TRUE, 0);
-#endif
   gtk_widget_show(chooser);
 }
 
@@ -751,12 +791,9 @@ create_toolbox ()
 {
   GtkWidget *window;
   GtkWidget *main_vbox;
-  GtkWidget *vbox;
-  gchar *accelfilename;
-#ifndef GNOME
+  GtkWidget *wrapbox;
   GtkWidget *menubar;
   GtkAccelGroup *accel_group;
-#endif
 
 #ifdef GNOME
   window = gnome_app_new ("Dia", _("Diagram Editor"));
@@ -768,6 +805,7 @@ create_toolbox ()
   gtk_window_set_wmclass (GTK_WINDOW (window), "toolbox_window",
 			  "Dia");
   gtk_window_set_policy(GTK_WINDOW(window), TRUE, TRUE, FALSE);
+  gtk_window_set_default_size(GTK_WINDOW(window), 146, 349);
 
   gtk_signal_connect (GTK_OBJECT (window), "delete_event",
 		      GTK_SIGNAL_FUNC (toolbox_delete),
@@ -786,21 +824,6 @@ create_toolbox ()
 #endif
   gtk_widget_show (main_vbox);
 
-#ifdef GNOME
-  gnome_toolbox_menus_create(window);
-#else
-  menus_get_toolbox_menubar(&menubar, &accel_group);
-  gtk_accel_group_attach (accel_group, GTK_OBJECT (window));
-  gtk_box_pack_start (GTK_BOX (main_vbox), menubar, FALSE, TRUE, 0);
-  gtk_widget_show (menubar);
-#endif
-  
-  accelfilename = dia_config_filename("menus/toolbox");
-  
-  if (accelfilename) {
-    gtk_item_factory_parse_rc(accelfilename);
-    g_free(accelfilename);
-  }
   /*  tooltips  */
   tool_tips = gtk_tooltips_new ();
 
@@ -808,23 +831,33 @@ create_toolbox ()
 			   &colors[11],
 			   &main_vbox->style->fg[GTK_STATE_NORMAL]);*/
 
-#ifdef USE_WRAPBOX
-  vbox = gtk_hwrap_box_new(FALSE);
-  gtk_wrap_box_set_aspect_ratio(GTK_WRAP_BOX(vbox), 143.0 / 283.0);
-  gtk_wrap_box_set_justify(GTK_WRAP_BOX(vbox), GTK_JUSTIFY_TOP);
-  gtk_wrap_box_set_line_justify(GTK_WRAP_BOX(vbox), GTK_JUSTIFY_LEFT);
-#else  
-  vbox = gtk_vbox_new (FALSE, 1);
+  wrapbox = gtk_hwrap_box_new(FALSE);
+  gtk_wrap_box_set_aspect_ratio(GTK_WRAP_BOX(wrapbox), 144.0 / 318.0);
+  gtk_wrap_box_set_justify(GTK_WRAP_BOX(wrapbox), GTK_JUSTIFY_TOP);
+  gtk_wrap_box_set_line_justify(GTK_WRAP_BOX(wrapbox), GTK_JUSTIFY_LEFT);
+
+
+  /* pack the rest of the stuff */
+  gtk_box_pack_end (GTK_BOX (main_vbox), wrapbox, TRUE, TRUE, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (wrapbox), 0);
+  gtk_widget_show (wrapbox);
+
+  create_tools (wrapbox);
+  create_sheets (wrapbox);
+  create_color_area (wrapbox);
+  create_lineprops_area (wrapbox);
+
+  /* menus -- initialised afterwards, because initing the display menus
+   * uses the tool buttons*/
+  menus_get_toolbox_menubar(&menubar, &accel_group);
+  gtk_accel_group_attach (accel_group, GTK_OBJECT (window));
+#ifdef GNOME
+  gnome_app_set_menus(GNOME_APP(window), GTK_MENU_BAR(menubar));
+#else
+  gtk_box_pack_start (GTK_BOX (main_vbox), menubar, FALSE, TRUE, 0);
+  gtk_widget_show (menubar);
 #endif
-  gtk_box_pack_start (GTK_BOX (main_vbox), vbox, TRUE, TRUE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), 0);
-  gtk_widget_show (vbox);
 
-  create_tools (vbox);
-  create_sheets (vbox);
-  create_color_area (vbox);
-  create_lineprops_area (vbox);
-  
   toolbox_shell = window;
 }
 
