@@ -25,17 +25,10 @@
 #include <gnome.h>
 #endif
 
-#ifdef GNOME
-extern void gnome_toolbox_menus_create(GtkWidget* app);
-extern GtkWidget * gnome_display_menus_create(void);
-#endif
+void menus_get_toolbox_menubar (GtkWidget **menubar, GtkAccelGroup **accel);
+void menus_get_image_menu      (GtkWidget **menu,    GtkAccelGroup **accel);
 
-extern void menus_get_toolbox_menubar(GtkWidget **menubar,
-				      GtkAccelGroup **accel);
-extern void menus_get_image_menu(GtkWidget **menu,
-				 GtkAccelGroup **accel);
-
-extern GtkWidget *menus_get_item_from_path(char *path);
+GtkWidget *menus_get_item_from_path(char *path);
 
 #endif /* MENUS_H */
 
