@@ -98,7 +98,7 @@ struct DiaPrefsTab prefs_tabs[] =
 
 struct DiaPrefsData prefs_data[] =
 {
-  { "reset_tools_after_create", PREF_BOOLEAN, PREF_OFFSET(reset_tools_after_create), &default_false, 0, N_("Reset tools after create:") },
+  { "reset_tools_after_create", PREF_BOOLEAN, PREF_OFFSET(reset_tools_after_create), &default_true, 0, N_("Reset tools after create:") },
   { "compress_save", PREF_BOOLEAN, PREF_OFFSET(compress_save), &default_true, 0, N_("Compress saved files:") },
   { "undo_depth", PREF_UINT, PREF_OFFSET(undo_depth), &default_undo_depth, 0, N_("Number of undo levels:") },
   { "reverse_rubberbanding_intersects", PREF_BOOLEAN, PREF_OFFSET(reverse_rubberbanding_intersects), &default_true, 0, N_("Reverse dragging selects\nintersecting objects:") },
@@ -359,13 +359,10 @@ prefs_load(void)
   fd = open(filename, O_RDONLY);
 
   if (fd < 0) {
-    char *homedir = getenv("HOME");
+    char *homedir = g_get_home_dir();
 
     g_free(filename);
-
-    filename = g_malloc(strlen(homedir)+strlen("/.diarc")+1);
-    strcpy(filename, getenv("HOME"));
-    strcat(filename, "/.diarc");
+    filename = g_strconcat(homedir, G_DIR_SEPARATOR_S ".diarc", NULL);
     fd = open(filename, O_RDONLY);
   }
   g_free(filename);
@@ -633,7 +630,7 @@ prefs_create_dialog(void)
   notebook = gtk_notebook_new ();
   gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
   gtk_box_pack_start (GTK_BOX (dialog_vbox), notebook, TRUE, TRUE, 0);
-  gtk_container_border_width (GTK_CONTAINER (notebook), 2);
+  gtk_container_set_border_width (GTK_CONTAINER (notebook), 2);
   gtk_widget_show (notebook);
 
   for (i=0;i<NUM_PREFS_TABS;i++) {
