@@ -28,6 +28,9 @@ static Arrow attributes_end_arrow = { ARROW_NONE, 0.8, 0.8 };
 static LineStyle attributes_linestyle = LINESTYLE_SOLID;
 static real attributes_dash_length = 1.0;
 
+static Font *attributes_font = NULL;
+static real attributes_font_height = 0.8;
+
 Color 
 attributes_get_foreground(void)
 {
@@ -114,3 +117,20 @@ attributes_set_default_line_style(LineStyle style, real dash_length)
   attributes_linestyle = style;
   attributes_dash_length = dash_length;
 }
+
+void
+attributes_get_default_font(Font **font, real *font_height)
+{
+  if (!attributes_font)
+    attributes_font = font_getfont("Courier");
+  if (font)
+    *font = attributes_font;
+  if (font_height)
+    *font_height = attributes_font_height;
+}
+void
+attributes_set_default_font(Font *font, real font_height)
+{
+  attributes_font = font;
+  attributes_font_height = font_height;
+}
