@@ -32,15 +32,15 @@ struct _Connection {
   Handle endpoint_handles[2];
 };
 
-extern void connection_update_handles(Connection *conn);
-extern void connection_update_boundingbox(Connection *conn);
-extern void connection_init(Connection *conn,
-			    int num_handles, int num_connections);
-extern void connection_destroy(Connection *conn);
-extern void connection_copy(Connection *from, Connection *to);
-extern void connection_save(Connection *conn, ObjectNode obj_node);
-extern void connection_load(Connection *conn, ObjectNode obj_node);
-extern void connection_move_handle(Connection *conn, HandleId id,
-				   Point *to, HandleMoveReason reason);
+void connection_update_handles(Connection *conn);
+void connection_update_boundingbox(Connection *conn);
+void connection_init(Connection *conn,
+		     int num_handles, int num_connections);
+void connection_destroy(Connection *conn);
+void connection_copy(Connection *from, Connection *to);
+void connection_save(Connection *conn, ObjectNode obj_node);
+void connection_load(Connection *conn, ObjectNode obj_node);
+void connection_move_handle(Connection *conn, HandleId id,
+			    Point *to, HandleMoveReason reason);
 
 #endif /* CONNECTION_H */
