@@ -2350,6 +2350,8 @@ umlclass_get_properties(UMLClass *umlclass)
     umlclass->properties_dialog = prop_dialog;
 
     vbox = gtk_vbox_new(FALSE, 0);
+    gtk_object_ref(GTK_OBJECT(vbox));
+    gtk_object_sink(GTK_OBJECT(vbox));
     prop_dialog->dialog = vbox;
 
     prop_dialog->current_attr = NULL;
