@@ -598,6 +598,8 @@ lifeline_get_properties(Lifeline *lif)
     properties_dialog = prop_dialog;
 
     dialog = gtk_vbox_new(FALSE, 0);
+    gtk_object_ref(GTK_OBJECT(dialog));
+    gtk_object_sink(GTK_OBJECT(dialog));
     prop_dialog->dialog = dialog;
     
     checkbox = gtk_check_button_new_with_label(_("Show focus of control:"));
